package pf::config::tenant;

=head1 NAME

pf::config::tenant -

=cut

=head1 DESCRIPTION

pf::config::tenant

=cut

use strict;
use warnings;
use pf::constants qw($DEFAULT_TENANT_ID);

our $CURRENT_TENANT = $DEFAULT_TENANT_ID;

=head2 reset_tenant

reset_tenant

=cut

sub reset_tenant {
    $pf::config::tenant::CURRENT_TENANT = $DEFAULT_TENANT_ID;
}

=head2 get_tenant

get_tenant

=cut

sub get_tenant {
    return $CURRENT_TENANT;
}

=head2 set_tenant

set_tenant

=cut

sub set_tenant {
    my ($tenant_id) = @_;
    $CURRENT_TENANT = $tenant_id // $DEFAULT_TENANT_ID;
}

=head1 AUTHOR

Inverse inc. <info@inverse.ca>

=head1 COPYRIGHT

Copyright (C) 2005-2020 Inverse inc.

=head1 LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
USA.

=cut

1;
